#!/bin/bash
#
# Copyright (c) 2020 Bubble, Inc.  All rights reserved. For personal (non-commercial) use, see license: https://getbubblenow.com/bubble-license/
#
BUBBLE_LOGS_FOLDER=/var/log/bubble
POSTGRES_LOGS_FOLDER=$(readlink -f "${BUBBLE_LOGS_FOLDER}"/postgresql)
REDIS_LOG_FLAG_KEY="bubble.StandardSelfNodeService.bubble_server_logs_enabled"

REDIS_LOG_FLAG_VALUE=$(echo "get ${REDIS_LOG_FLAG_KEY}" | redis-cli | xargs echo | tr '[:upper:]' '[:lower:]')

if [[ ${REDIS_LOG_FLAG_VALUE} == true ]]; then
  is_reload_needed=false
  is_psql_restart_needed=false
  # Cannot use -L option in find here as links are actually find's target:
  for logFile in $(find "${BUBBLE_LOGS_FOLDER}"/* -type l ! -name postgresql); do
    rm "${logFile}"
    touch "${logFile}"
    is_reload_needed=true
  done
  for psqlLogFile in $(find "${POSTGRES_LOGS_FOLDER}"/* -type l); do
    rm "${psqlLogFile}"
    is_psql_restart_needed=true
  done

  if [[ ${is_psql_restart_needed} == true ]]; then
    service postgresql restart
  fi
  if [[ ${is_reload_needed} == true ]]; then
    supervisorctl reload
  fi
else
  # following dir link with -L option, so no need for special postgres for loop in this case:
  for logFile in $(find -L "${BUBBLE_LOGS_FOLDER}"/* -type f); do
    ln -sf /dev/null "${logFile}"
  done
fi
